==> ejc-assistrmat-impl-3.0.0-20220914.091218-197-sources.jar: com/ejianc/business/outrmat/settle/bean/OutRmatSettleOtherEntity.java <==
package com.ejianc.business.outrmat.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 结算单-其他费用
 *
 * @author generator
 */
@TableName("ejc_outrmat_settle_other")
public class OutRmatSettleOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "source_type")
    private Integer sourceType; // 来源类型：0-新增，1-合同代入
    @TableField(value = "cost_name")
    private String costName; // 费用名称
    @TableField(value = "unit_tax_price")
    private BigDecimal unitTaxPrice; // 单价
    @TableField(value = "unit_price")
    private BigDecimal unitPrice; // 单价(无税)
    @TableField(value = "tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value = "contract_num")
    private BigDecimal contractNum; // 合同数量
    @TableField(value = "settle_num")
    private BigDecimal settleNum; // 本期结算量
    @TableField(value = "settle_tax_mny")
    private BigDecimal settleTaxMny; // 本期结算金额
    @TableField(value = "settle_mny")
    private BigDecimal settleMny; // 本期结算金额(无税)
    @TableField(value = "settle_tax")
    private BigDecimal settleTax; // 税额
    @TableField(value = "memo")
    private String memo; // 备注
    
    
    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public BigDecimal getSettleNum() {
        return settleNum;
    }

    public void setSettleNum(BigDecimal settleNum) {
        this.settleNum = settleNum;
    }

    public BigDecimal getSettleTaxMny() {
        return settleTaxMny;
    }

    public void setSettleTaxMny(BigDecimal settleTaxMny) {
        this.settleTaxMny = settleTaxMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getSettleTax() {
        return settleTax;
    }

    public void setSettleTax(BigDecimal settleTax) {
        this.settleTax = settleTax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-assistrmat-impl-3.0.0-20230406.100747-341-sources.jar: com/ejianc/business/outrmat/settle/bean/OutRmatSettleOtherEntity.java <==
package com.ejianc.business.outrmat.settle.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 结算单-其他费用
 *
 * @author generator
 */
@TableName("ejc_outrmat_settle_other")
public class OutRmatSettleOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "source_type")
    private Integer sourceType; // 来源类型：0-新增，1-合同代入 2-退赔抓取
    @TableField(value = "cost_name")
    private String costName; // 费用名称
    @TableField(value = "unit_tax_price")
    private BigDecimal unitTaxPrice; // 单价
    @TableField(value = "unit_price")
    private BigDecimal unitPrice; // 单价(无税)
    @TableField(value = "tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value = "contract_num")
    private BigDecimal contractNum; // 合同数量
    @TableField(value = "settle_num")
    private BigDecimal settleNum; // 本期结算量
    @TableField(value = "settle_tax_mny")
    private BigDecimal settleTaxMny; // 本期结算金额
    @TableField(value = "settle_mny")
    private BigDecimal settleMny; // 本期结算金额(无税)
    @TableField(value = "settle_tax")
    private BigDecimal settleTax; // 税额
    @TableField(value = "memo")
    private String memo; // 备注
    
    
    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public BigDecimal getSettleNum() {
        return settleNum;
    }

    public void setSettleNum(BigDecimal settleNum) {
        this.settleNum = settleNum;
    }

    public BigDecimal getSettleTaxMny() {
        return settleTaxMny;
    }

    public void setSettleTaxMny(BigDecimal settleTaxMny) {
        this.settleTaxMny = settleTaxMny;
    }

    public BigDecimal getSettleMny() {
        return settleMny;
    }

    public void setSettleMny(BigDecimal settleMny) {
        this.settleMny = settleMny;
    }

    public BigDecimal getSettleTax() {
        return settleTax;
    }

    public void setSettleTax(BigDecimal settleTax) {
        this.settleTax = settleTax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
